@@ -1,5 +1,11 @@
 skip_if_no_pycox()
 
+set.seed(1)
+np <- reticulate::import("numpy")
+np$random$seed(1L)
+torch <- reticulate::import("torch")
+torch$manual_seed(1L)
+
 test_that("get_pycox_optim", {
   net <- build_pytorch_net(1L, 1L, 1L)
   expect_is(get_pycox_optim("adadelta", net),  "torch.optim.adadelta.Adadelta")
@@ -11,7 +17,7 @@ test_that("get_pycox_optim", {
   expect_is(get_pycox_optim("rmsprop", net),  "torch.optim.rmsprop.RMSprop")
   expect_is(get_pycox_optim("rprop", net),  "torch.optim.rprop.Rprop")
   expect_is(get_pycox_optim("sgd", net),  "torch.optim.sgd.SGD")
-  expect_is(get_pycox_optim("sparse_adam", net),  "torch.optim.sparse_adam.SparseAdam")
+  # expect_is(get_pycox_optim("sparse_adam", net),  "torch.optim.sparse_adam.SparseAdam")
 })
 
 test_that("get_pycox_init", {
